@@ -13,7 +13,7 @@ use vars qw( @EXPORT_OK %EXPORT_TAGS );
 %EXPORT_TAGS = ( 'all' => \@EXPORT_OK );
 
 use vars '$VERSION';
-$VERSION = '1.10';
+$VERSION = '1.11';
 
 use vars '@Scalars';
 @Scalars = (
@@ -109,6 +109,7 @@ use vars '@Filehandles';
 
 use vars '@Functions';
 @Functions = qw(
+    __SUB__
     AUTOLOAD
     BEGIN
     DESTROY
@@ -152,6 +153,7 @@ use vars '@Functions';
     endservent
     eof
     eval
+    evalbytes
     exec
     exists
     exit
